## Dependencies

Install [`solc`](https://docs.soliditylang.org/en/latest/installing-solidity.html).
You might have to install `solc-select` to set your solidity compiler version.
ABIs and pypechain types are generated automatically with the `process_contracts` pytest fixture.
